# TransferredToAccountingStatus

Status showing whether the journal entry has been transferred to an accounting system. This field cannot be changed after the summary journal entry has been cancelled. Note:** The Zuora Finance Override Transferred to Accounting permission is required to change `transferredToAccounting` from `Yes` to any other value.

## Enum

* `NO` (value: `'No'`)

* `PROCESSING` (value: `'Processing'`)

* `YES` (value: `'Yes'`)

* `ERROR` (value: `'Error'`)

* `IGNORE` (value: `'Ignore'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


